==> ah-form-builder-sample-0.6.20.tgz: package/es/utils/conditional-logic/ConditionItem.js <==
var _jsxFileName = "/var/apps/ah-form-builder/src/utils/conditional-logic/ConditionItem.js";

function _extends() { _extends = Object.assign || function (target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i]; for (var key in source) { if (Object.prototype.hasOwnProperty.call(source, key)) { target[key] = source[key]; } } } return target; }; return _extends.apply(this, arguments); }

import React from 'react';
import SearchableSelect from "../selects/SearchableSelect";
import TextInput from "../inputs/TextInput";
import MultiSelect from "../selects/MultiSelect";
import Typography from "@material-ui/core/Typography";
import Divider from "@material-ui/core/Divider";
import IconButton from "@material-ui/core/IconButton";
import RemoveIcon from '@material-ui/icons/Clear';
export default function ConditionItem(props) {
  var _this = this;

  var getOptions = function getOptions() {
    var options = [{
      label: 'Contains',
      value: 'contain'
    }, {
      label: 'Starts with',
      value: 'prefix'
    }, {
      label: 'Ends with',
      value: 'postfix'
    }];

    if (props.condition.field) {
      if (props.multiFields.includes(props.condition.field)) {
        options = [{
          label: 'Includes',
          value: 'includes'
        }, {
          label: 'Excludes',
          value: 'excludes'
        }];
      } else if (props.singleFields.includes(props.condition.field)) {
        options = [{
          label: 'Is',
          value: 'is'
        }, {
          label: 'Is Not',
          value: 'not'
        }];
      } else if (props.numberFields.includes(props.condition.field)) {
        options = [{
          label: 'Equals',
          value: 'equal'
        }, {
          label: 'Greater than',
          value: 'greater'
        }, {
          label: 'Less than',
          value: 'less'
        }];
      }
    }

    return options;
  };

  var getType = function getType() {
    var type = 'text';

    if (props.condition.field) {
      if (props.multiFields.includes(props.condition.field)) {
        type = 'multiple';
      } else if (props.singleFields.includes(props.condition.field)) {
        type = 'single';
      } else if (props.numberFields.includes(props.condition.field)) {
        type = 'number';
      }
    }

    return type;
  };

  var _handleChange = function handleChange(val, name) {
    var _extends2;

    var condition = _extends({}, props.condition, (_extends2 = {}, _extends2[name] = val, _extends2));

    props.handleChange(condition);
  };

  var renderOptions = function renderOptions() {
    var type = getType();

    if (type === 'number') {
      return /*#__PURE__*/React.createElement(TextInput, {
        placeholder: "Value",
        type: "number",
        value: props.condition.value,
        handleChange: function handleChange(e) {
          return _handleChange(e.target.value, 'value');
        },
        error: props.errors.value,
        __self: _this,
        __source: {
          fileName: _jsxFileName,
          lineNumber: 68,
          columnNumber: 9
        }
      });
    } else if (type === 'single') {
      return /*#__PURE__*/React.createElement(SearchableSelect, {
        placeholder: "Value",
        options: props.options[props.condition.field],
        value: props.condition.value,
        handleChange: function handleChange(e) {
          return _handleChange(e.target.value, 'value');
        },
        error: props.errors.value,
        labelProp: "name",
        valueProp: "id",
        __self: _this,
        __source: {
          fileName: _jsxFileName,
          lineNumber: 72,
          columnNumber: 9
        }
      });
    } else if (type === 'multiple') {
      return /*#__PURE__*/React.createElement(MultiSelect, {
        placeholder: "Value",
        options: props.options[props.condition.field],
        value: props.condition.value,
        handleChange: function handleChange(e) {
          return _handleChange(e.target.value, 'value');
        },
        error: props.errors.value,
        labelProp: "name",
        valueProp: "id",
        __self: _this,
        __source: {
          fileName: _jsxFileName,
          lineNumber: 76,
          columnNumber: 9
        }
      });
    } else {
      return /*#__PURE__*/React.createElement(TextInput, {
        placeholder: "Value",
        value: props.condition.value,
        handleChange: function handleChange(e) {
          return _handleChange(e.target.value, 'value');
        },
        error: props.errors.value,
        __self: _this,
        __source: {
          fileName: _jsxFileName,
          lineNumber: 80,
          columnNumber: 9
        }
      });
    }
  };

  return /*#__PURE__*/React.createElement("div", {
    className: "row mx-0 pt-2 pb-3 px-2 conditions-item-main mb-3",
    __self: this,
    __source: {
      fileName: _jsxFileName,
      lineNumber: 86,
      columnNumber: 5
    }
  }, /*#__PURE__*/React.createElement("div", {
    className: "col-md-10 pl-0",
    __self: this,
    __source: {
      fileName: _jsxFileName,
      lineNumber: 87,
      columnNumber: 7
    }
  }, /*#__PURE__*/React.createElement(Typography, {
    variant: "button",
    __self: this,
    __source: {
      fileName: _jsxFileName,
      lineNumber: 88,
      columnNumber: 9
    }
  }, "Condition #", props.index + 1)), /*#__PURE__*/React.createElement("div", {
    className: "col-md-2 text-right pr-0",
    __self: this,
    __source: {
      fileName: _jsxFileName,
      lineNumber: 90,
      columnNumber: 7
    }
  }, /*#__PURE__*/React.createElement(IconButton, {
    size: "small",
    onClick: props.deleteCondition,
    __self: this,
    __source: {
      fileName: _jsxFileName,
      lineNumber: 91,
      columnNumber: 9
    }
  }, /*#__PURE__*/React.createElement(RemoveIcon, {
    fontSize: "small",
    className: "pull-right",
    color: "action",
    __self: this,
    __source: {
      fileName: _jsxFileName,
      lineNumber: 91,
      columnNumber: 66
    }
  }))), /*#__PURE__*/React.createElement("hr", {
    className: "condition-divider mt-0 mb-2",
    __self: this,
    __source: {
      fileName: _jsxFileName,
      lineNumber: 93,
      columnNumber: 7
    }
  }), /*#__PURE__*/React.createElement("div", {
    className: "col-md-12 px-1 mb-2",
    __self: this,
    __source: {
      fileName: _jsxFileName,
      lineNumber: 94,
      columnNumber: 7
    }
  }, /*#__PURE__*/React.createElement(SearchableSelect, {
    placeholder: "Field",
    options: props.fields,
    labelProp: "name",
    valueProp: "machineName",
    value: props.condition.field,
    handleChange: function handleChange(e) {
      return _handleChange(e.target.value, 'field');
    },
    error: props.errors.field,
    __self: this,
    __source: {
      fileName: _jsxFileName,
      lineNumber: 95,
      columnNumber: 9
    }
  })), /*#__PURE__*/React.createElement("div", {
    className: "col-md-6 pl-1",
    __self: this,
    __source: {
      fileName: _jsxFileName,
      lineNumber: 97,
      columnNumber: 7
    }
  }, /*#__PURE__*/React.createElement(SearchableSelect, {
    placeholder: "Operator",
    options: getOptions(),
    value: props.condition.operator,
    handleChange: function handleChange(e) {
      return _handleChange(e.target.value, 'operator');
    },
    disableClearable: true,
    error: props.errors.operator,
    __self: this,
    __source: {
      fileName: _jsxFileName,
      lineNumber: 98,
      columnNumber: 9
    }
  })), /*#__PURE__*/React.createElement("div", {
    className: "col-md-6 pr-1",
    __self: this,
    __source: {
      fileName: _jsxFileName,
      lineNumber: 100,
      columnNumber: 7
    }
  }, renderOptions()));
}

==> ah-form-builder-sample-0.6.86.tgz: package/es/utils/conditional-logic/ConditionItem.js <==
var _jsxFileName = "/var/www/html/formbuilder/src/utils/conditional-logic/ConditionItem.js";

function _extends() { _extends = Object.assign || function (target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i]; for (var key in source) { if (Object.prototype.hasOwnProperty.call(source, key)) { target[key] = source[key]; } } } return target; }; return _extends.apply(this, arguments); }

import React from 'react';
import SearchableSelect from "../selects/SearchableSelect";
import TextInput from "../inputs/TextInput";
import MultiSelect from "../selects/MultiSelect";
import Typography from "@material-ui/core/Typography";
import Divider from "@material-ui/core/Divider";
import IconButton from "@material-ui/core/IconButton";
import RemoveIcon from '@material-ui/icons/Clear';
import { Grid } from '@material-ui/core';
export default function ConditionItem(props) {
  var _this = this;

  var getOptions = function getOptions() {
    var options = [{
      label: 'Contains',
      value: 'contain'
    }, {
      label: 'Starts with',
      value: 'prefix'
    }, {
      label: 'Ends with',
      value: 'postfix'
    }];

    if (props.condition.field) {
      if (props.multiFields.includes(props.condition.field)) {
        options = [{
          label: 'Includes',
          value: 'includes'
        }, {
          label: 'Include Any',
          value: 'include-any'
        }, {
          label: 'Excludes',
          value: 'excludes'
        }, {
          label: 'Exclude Any',
          value: 'exclude-any'
        }];
      } else if (props.singleFields.includes(props.condition.field)) {
        options = [{
          label: 'Is',
          value: 'is'
        }, {
          label: 'Is Not',
          value: 'not'
        }];
      } else if (props.numberFields.includes(props.condition.field)) {
        options = [{
          label: 'Equals',
          value: 'equal'
        }, {
          label: 'Greater than',
          value: 'greater'
        }, {
          label: 'Less than',
          value: 'less'
        }];
      }
    }

    return options;
  };

  var getType = function getType() {
    var type = 'text';

    if (props.condition.field) {
      if (props.multiFields.includes(props.condition.field)) {
        type = 'multiple';
      } else if (props.singleFields.includes(props.condition.field)) {
        type = 'single';
      } else if (props.numberFields.includes(props.condition.field)) {
        type = 'number';
      }
    }

    return type;
  };

  var _handleChange = function handleChange(val, name) {
    var _extends2;

    var condition = _extends({}, props.condition, (_extends2 = {}, _extends2[name] = val, _extends2));

    props.handleChange(condition);
  };

  var renderOptions = function renderOptions() {
    var type = getType();

    if (type === 'number') {
      return /*#__PURE__*/React.createElement(TextInput, {
        placeholder: "Value",
        type: "number",
        value: props.condition.value,
        handleChange: function handleChange(e) {
          return _handleChange(e.target.value, 'value');
        },
        error: props.errors.value,
        __self: _this,
        __source: {
          fileName: _jsxFileName,
          lineNumber: 71,
          columnNumber: 9
        }
      });
    } else if (type === 'single') {
      return /*#__PURE__*/React.createElement(SearchableSelect, {
        disableClearable: true,
        placeholder: "Value",
        options: props.options[props.condition.field],
        value: props.condition.value,
        handleChange: function handleChange(e) {
          return _handleChange(e.target.value, 'value');
        },
        error: props.errors.value,
        labelProp: "name",
        valueProp: "id",
        __self: _this,
        __source: {
          fileName: _jsxFileName,
          lineNumber: 75,
          columnNumber: 9
        }
      });
    } else if (type === 'multiple') {
      return /*#__PURE__*/React.createElement(MultiSelect, {
        placeholder: "Value",
        options: props.options[props.condition.field],
        value: props.condition.value,
        handleChange: function handleChange(e) {
          return _handleChange(e.target.value, 'value');
        },
        error: props.errors.value,
        labelProp: "name",
        valueProp: "id",
        __self: _this,
        __source: {
          fileName: _jsxFileName,
          lineNumber: 79,
          columnNumber: 9
        }
      });
    } else {
      return /*#__PURE__*/React.createElement(TextInput, {
        placeholder: "Value",
        value: props.condition.value,
        handleChange: function handleChange(e) {
          return _handleChange(e.target.value, 'value');
        },
        error: props.errors.value,
        __self: _this,
        __source: {
          fileName: _jsxFileName,
          lineNumber: 83,
          columnNumber: 9
        }
      });
    }
  };

  return /*#__PURE__*/React.createElement(Grid, {
    container: true,
    className: "ahfb-mx-0 ahfb-pt-2 ahfb-pb-3 ahfb-px-2 ahfb-conditions-item-main ahfb-mb-3",
    __self: this,
    __source: {
      fileName: _jsxFileName,
      lineNumber: 89,
      columnNumber: 5
    }
  }, /*#__PURE__*/React.createElement(Grid, {
    item: true,
    xs: 10,
    className: "ahfb-pl-0",
    __self: this,
    __source: {
      fileName: _jsxFileName,
      lineNumber: 90,
      columnNumber: 7
    }
  }, /*#__PURE__*/React.createElement(Typography, {
    variant: "button",
    __self: this,
    __source: {
      fileName: _jsxFileName,
      lineNumber: 91,
      columnNumber: 9
    }
  }, "Condition #", props.index + 1)), /*#__PURE__*/React.createElement(Grid, {
    item: true,
    xs: 2,
    className: "ahfb-text-right ahfb-pr-0",
    __self: this,
    __source: {
      fileName: _jsxFileName,
      lineNumber: 93,
      columnNumber: 7
    }
  }, /*#__PURE__*/React.createElement(IconButton, {
    size: "small",
    onClick: props.deleteCondition,
    __self: this,
    __source: {
      fileName: _jsxFileName,
      lineNumber: 94,
      columnNumber: 9
    }
  }, /*#__PURE__*/React.createElement(RemoveIcon, {
    fontSize: "small",
    className: "ahfb-pull-right",
    color: "action",
    __self: this,
    __source: {
      fileName: _jsxFileName,
      lineNumber: 94,
      columnNumber: 66
    }
  }))), /*#__PURE__*/React.createElement("hr", {
    className: "ahfb-condition-divider ahfb-mt-0 ahfb-mb-2",
    __self: this,
    __source: {
      fileName: _jsxFileName,
      lineNumber: 96,
      columnNumber: 7
    }
  }), /*#__PURE__*/React.createElement(Grid, {
    item: true,
    xs: 12,
    className: "ahfb-px-1 ahfb-mb-2",
    __self: this,
    __source: {
      fileName: _jsxFileName,
      lineNumber: 97,
      columnNumber: 7
    }
  }, /*#__PURE__*/React.createElement(SearchableSelect, {
    disableClearable: true,
    placeholder: "Field",
    options: props.fields,
    labelProp: "name",
    valueProp: "machineName",
    value: props.condition.field,
    handleChange: function handleChange(e) {
      return _handleChange(e.target.value, 'field');
    },
    error: props.errors.field,
    __self: this,
    __source: {
      fileName: _jsxFileName,
      lineNumber: 98,
      columnNumber: 9
    }
  })), /*#__PURE__*/React.createElement(Grid, {
    item: true,
    xs: 6,
    className: "ahfb-pr-1",
    __self: this,
    __source: {
      fileName: _jsxFileName,
      lineNumber: 100,
      columnNumber: 7
    }
  }, /*#__PURE__*/React.createElement(SearchableSelect, {
    disableClearable: true,
    placeholder: "Operator",
    options: getOptions(),
    value: props.condition.operator,
    handleChange: function handleChange(e) {
      return _handleChange(e.target.value, 'operator');
    },
    error: props.errors.operator,
    __self: this,
    __source: {
      fileName: _jsxFileName,
      lineNumber: 101,
      columnNumber: 9
    }
  })), /*#__PURE__*/React.createElement(Grid, {
    item: true,
    xs: 6,
    className: "ahfb-pl-1",
    __self: this,
    __source: {
      fileName: _jsxFileName,
      lineNumber: 103,
      columnNumber: 7
    }
  }, renderOptions()));
}
